@@ -15,9 +15,9 @@ are_site_models <- function(
   x
 ) {
   if (is.null(x)) return(FALSE)
-  if (is_site_model(x)) return(TRUE) # nolint beautier function
+  if (beautier::is_site_model(x)) return(TRUE)
   for (i in x) {
-    if (!is_site_model(i)) return(FALSE) # nolint beautier function
+    if (!beautier::is_site_model(i)) return(FALSE)
   }
   return(TRUE)
 }
