@@ -3,15 +3,15 @@
 #' @param regex regex string
 #' @return index of the line
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 find_last_regex_line <- function(lines, regex) {
 
   for (i in rev(seq_along(lines))) {
     match <- stringr::str_extract(
-      str = lines[i],
+      string = lines[i],
       pattern = regex
     )
-    if (!is_one_na(match)) return(i) # nolint beautier function
+    if (!beautier::is_one_na(match)) return(i)
   }
   NA
 }
