@@ -15,7 +15,7 @@ tree_priors_to_xml_tracelog <- function(
   text <- NULL
   for (tree_prior in tree_priors) {
     text <- c(text,
-      tree_prior_to_xml_tracelog(tree_prior)
+      beautier::tree_prior_to_xml_tracelog(tree_prior)
     )
   }
   text
